@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import unittest
 
+from yandex_checkout import RefundSource
 from yandex_checkout.domain.models.amount import Amount
 from yandex_checkout.domain.models.currency import Currency
 from yandex_checkout.domain.response.refund_response import RefundResponse
@@ -18,7 +19,20 @@ class TestRefundResponse(unittest.TestCase):
             },
             'receipt_registration': 'pending',
             'comment': 'test comment',
-            'status': 'pending'
+            'status': 'pending',
+            'sources': [
+                {
+                    'account_id': '79990000000',
+                    "amount": {
+                        "value": 100.01,
+                        "currency": Currency.RUB
+                    },
+                    "platform_fee_amount": {
+                        "value": 10.01,
+                        "currency": Currency.RUB
+                    }
+                }
+            ]
         })
 
         self.assertEqual(response.id, '21b23b5b-000f-5061-a000-0674e49a8c10')
@@ -27,4 +41,5 @@ class TestRefundResponse(unittest.TestCase):
         self.assertEqual(response.receipt_registration, 'pending')
         self.assertEqual(response.comment, 'test comment')
         self.assertIsInstance(response.amount, Amount)
+        self.assertIsInstance(response.sources[0], RefundSource)
         self.assertEqual(response.status, 'pending')
