@@ -13,6 +13,8 @@ class RefundSource(BaseObject):
 
     __amount = None
 
+    __platform_fee_amount = None
+
     @property
     def account_id(self):
         return self.__account_id
@@ -33,3 +35,16 @@ class RefundSource(BaseObject):
             self.__amount = value
         else:
             raise TypeError('Invalid amount value type')
+
+    @property
+    def platform_fee_amount(self):
+        return self.__platform_fee_amount
+
+    @platform_fee_amount.setter
+    def platform_fee_amount(self, value):
+        if isinstance(value, dict):
+            self.__platform_fee_amount = Amount(value)
+        elif isinstance(value, Amount):
+            self.__platform_fee_amount = value
+        else:
+            raise TypeError('Invalid platform_fee_amount value type')
