@@ -13,6 +13,8 @@ class TransferResponse(BaseObject):
 
     __amount = None
 
+    __platform_fee_amount = None
+
     __status = None
 
     @property
@@ -36,6 +38,19 @@ class TransferResponse(BaseObject):
         else:
             raise TypeError('Invalid amount value type')
 
+    @property
+    def platform_fee_amount(self):
+        return self.__platform_fee_amount
+
+    @platform_fee_amount.setter
+    def platform_fee_amount(self, value):
+        if isinstance(value, dict):
+            self.__platform_fee_amount = Amount(value)
+        elif isinstance(value, Amount):
+            self.__platform_fee_amount = value
+        else:
+            raise TypeError('Invalid platform_fee_amount value type')
+
     @property
     def status(self):
         return self.__status
